powered by
This is the biquadratic kernel function, that weights observations by their distances to the target observation.
Bnk_func(x0k, Xk, bw.bnk)
Numeric scalar. One univariate covariate value of interest from one observation.
Numerical vector. The vector of the same covariate from observations
The bandwith scalar parameter.
This function returns a list of kernel weights with the same length of input Xk.
Xk
wang2009locallyQTOCen
# NOT RUN { Bnk_func(x0k=0, Xk=c(-5:5), bw.bnk=10) # }
Run the code above in your browser using DataLab