tauhat_func: Kernel-based Local Kaplan-Meier Estimator for the Conditional Probability of the Survival Time
Description
This function estimates the value of
$$F(T <= y_0 \mid x_0),$$
the conditional cumulative distribution function of a survival time \(T\)
given covaraites vector \(x_0\)
at value \(y_0\).
This estimator is described in detail in wang2009locallyQTOCen.
Usage
tauhat_func(y0, x0, z, x, delta, bw)
Arguments
y0
the vector of censored outcome of a single observation
x0
the vector of given covariate of a single observation
z
observed vector of response variable from observed data
x
the observed matrix of covariates, the dimension is # of observations by number of covariates.
Note that the vector of ones should NOT be included in x.
delta
the vector of censoring indicators
bw
the scalar bandwidth parameter in kernel
Details
For cases with multivariate covariates, we adopted a product kernel.
For example, in the bivariate case we use $$K(x_1, x_2) = K_1(x_1) K_2(x_2),$$
where \(K_1\) and \(K_2\) are both biquadratickernel functions.